@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: dns
 version: 2.0.2
-id: dns-2.0.2-ac237de79a0ae5f78508e767a0b30196
-key: dns_6914X25iTja2Dj3MmxOUhN
+id: dns-2.0.2-5c05baf740cd5d8d2ce8cd6f28e05311
+key: dns_0InE8ViHkR0H1v6cVMjVJ6
 license: BSD3
 maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
 synopsis: DNS library in Haskell
@@ -22,21 +22,21 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/dns-2.0.2
-hs-libraries: HSdns-2.0.2-6914X25iTja2Dj3MmxOUhN
+hs-libraries: HSdns-2.0.2-0InE8ViHkR0H1v6cVMjVJ6
 depends:
     attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
-    conduit-extra-1.1.13.1-b0a6afe4d52c8bc50dff37cca54ee4a6
+    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
+    conduit-extra-1.1.13.1-cf2e2742d7d01907ed25c65d155b9a5e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
-    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
+    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
 haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
 haddock-html: /usr/share/doc/haskell-dns/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
